==> mono_2.6.7.orig.tar.gz: mono-2.6.7/mono/mini/simd-methods.h <==
SIMD_METHOD("AddSub", SN_AddSub)
SIMD_METHOD("AddWithSaturation", SN_AddWithSaturation)
SIMD_METHOD("AndNot", SN_AndNot)
SIMD_METHOD("Average", SN_Average)
SIMD_METHOD("CompareEqual", SN_CompareEqual)
SIMD_METHOD("CompareGreaterThan", SN_CompareGreaterThan)
SIMD_METHOD("CompareLessEqual", SN_CompareLessEqual)
SIMD_METHOD("CompareLessThan", SN_CompareLessThan)
SIMD_METHOD("CompareNotEqual", SN_CompareNotEqual)
SIMD_METHOD("CompareNotLessEqual", SN_CompareNotLessEqual)
SIMD_METHOD("CompareNotLessThan", SN_CompareNotLessThan)
SIMD_METHOD("CompareOrdered", SN_CompareOrdered)
SIMD_METHOD("CompareUnordered", SN_CompareUnordered)
SIMD_METHOD(".ctor", SN_ctor)
SIMD_METHOD("Duplicate", SN_Duplicate)
SIMD_METHOD("DuplicateHigh", SN_DuplicateHigh)
SIMD_METHOD("DuplicateLow", SN_DuplicateLow)
SIMD_METHOD("ExtractByteMask", SN_ExtractByteMask)
SIMD_METHOD("get_W", SN_get_W)
SIMD_METHOD("get_X", SN_get_X)
SIMD_METHOD("get_Y", SN_get_Y)
SIMD_METHOD("get_Z", SN_get_Z)
SIMD_METHOD("get_V0", SN_get_V0)
SIMD_METHOD("get_V1", SN_get_V1)
SIMD_METHOD("get_V2", SN_get_V2)
SIMD_METHOD("get_V3", SN_get_V3)
SIMD_METHOD("get_V4", SN_get_V4)
SIMD_METHOD("get_V5", SN_get_V5)
SIMD_METHOD("get_V6", SN_get_V6)
SIMD_METHOD("get_V7", SN_get_V7)
SIMD_METHOD("get_V8", SN_get_V8)
SIMD_METHOD("get_V9", SN_get_V9)
SIMD_METHOD("get_V10", SN_get_V10)
SIMD_METHOD("get_V11", SN_get_V11)
SIMD_METHOD("get_V12", SN_get_V12)
SIMD_METHOD("get_V13", SN_get_V13)
SIMD_METHOD("get_V14", SN_get_V14)
SIMD_METHOD("get_V15", SN_get_V15)
SIMD_METHOD("set_W", SN_set_W)
SIMD_METHOD("set_X", SN_set_X)
SIMD_METHOD("set_Y", SN_set_Y)
SIMD_METHOD("set_Z", SN_set_Z)
SIMD_METHOD("set_V0", SN_set_V0)
SIMD_METHOD("set_V1", SN_set_V1)
SIMD_METHOD("set_V2", SN_set_V2)
SIMD_METHOD("set_V3", SN_set_V3)
SIMD_METHOD("set_V4", SN_set_V4)
SIMD_METHOD("set_V5", SN_set_V5)
SIMD_METHOD("set_V6", SN_set_V6)
SIMD_METHOD("set_V7", SN_set_V7)
SIMD_METHOD("set_V8", SN_set_V8)
SIMD_METHOD("set_V9", SN_set_V9)
SIMD_METHOD("set_V10", SN_set_V10)
SIMD_METHOD("set_V11", SN_set_V11)
SIMD_METHOD("set_V12", SN_set_V12)
SIMD_METHOD("set_V13", SN_set_V13)
SIMD_METHOD("set_V14", SN_set_V14)
SIMD_METHOD("set_V15", SN_set_V15)
SIMD_METHOD("HorizontalAdd", SN_HorizontalAdd)
SIMD_METHOD("HorizontalSub", SN_HorizontalSub)
SIMD_METHOD("InterleaveHigh", SN_InterleaveHigh)
SIMD_METHOD("InterleaveLow", SN_InterleaveLow)
SIMD_METHOD("InvSqrt", SN_InvSqrt)
SIMD_METHOD("LoadAligned", SN_LoadAligned)
SIMD_METHOD("Max", SN_Max)
SIMD_METHOD("Min", SN_Min)
SIMD_METHOD("MultiplyStoreHigh", SN_MultiplyStoreHigh)
SIMD_METHOD("op_Addition", SN_op_Addition)
SIMD_METHOD("op_BitwiseAnd", SN_op_BitwiseAnd)
SIMD_METHOD("op_BitwiseOr", SN_op_BitwiseOr)
SIMD_METHOD("op_Division", SN_op_Division)
SIMD_METHOD("op_Equality", SN_op_Equality)
SIMD_METHOD("op_ExclusiveOr", SN_op_ExclusiveOr)
SIMD_METHOD("op_Explicit", SN_op_Explicit)
SIMD_METHOD("op_Inequality", SN_op_Inequality)
SIMD_METHOD("op_LeftShift", SN_op_LeftShift)
SIMD_METHOD("op_Multiply", SN_op_Multiply)
SIMD_METHOD("op_RightShift", SN_op_RightShift)
SIMD_METHOD("op_Subtraction", SN_op_Subtraction)
SIMD_METHOD("PackWithSignedSaturation", SN_PackWithSignedSaturation)
SIMD_METHOD("PackWithUnsignedSaturation", SN_PackWithUnsignedSaturation)
SIMD_METHOD("PrefetchTemporalAllCacheLevels", SN_PrefetchTemporalAllCacheLevels)
SIMD_METHOD("PrefetchTemporal1stLevelCache", SN_PrefetchTemporal1stLevelCache)
SIMD_METHOD("PrefetchTemporal2ndLevelCache", SN_PrefetchTemporal2ndLevelCache)
SIMD_METHOD("PrefetchNonTemporal", SN_PrefetchNonTemporal)
SIMD_METHOD("Reciprocal", SN_Reciprocal)
SIMD_METHOD("ArithmeticRightShift", SN_ArithmeticRightShift)
SIMD_METHOD("LogicalRightShift", SN_LogicalRightShift)
SIMD_METHOD("ShuffleHigh", SN_ShuffleHigh)
SIMD_METHOD("ShuffleLow", SN_ShuffleLow)
SIMD_METHOD("Shuffle", SN_Shuffle)
SIMD_METHOD("SignedPackWithSignedSaturation", SN_SignedPackWithSignedSaturation)
SIMD_METHOD("SignedPackWithUnsignedSaturation", SN_SignedPackWithUnsignedSaturation)
SIMD_METHOD("Sqrt", SN_Sqrt)
SIMD_METHOD("StoreAligned", SN_StoreAligned)
SIMD_METHOD("StoreNonTemporal", SN_StoreNonTemporal)
SIMD_METHOD("SubtractWithSaturation", SN_SubtractWithSaturation)
SIMD_METHOD("SumOfAbsoluteDifferences", SN_SumOfAbsoluteDifferences)
SIMD_METHOD("UnpackHigh", SN_UnpackHigh)
SIMD_METHOD("UnpackLow", SN_UnpackLow)

==> mono_4.2.1.102+dfsg2.orig.tar.gz: mono-4.2.1+dfsg2/mono/mini/simd-methods.h <==
SIMD_METHOD("AddSub", SN_AddSub)
SIMD_METHOD("AddWithSaturation", SN_AddWithSaturation)
SIMD_METHOD("AndNot", SN_AndNot)
SIMD_METHOD("Average", SN_Average)
SIMD_METHOD("CompareEqual", SN_CompareEqual)
SIMD_METHOD("CompareGreaterThan", SN_CompareGreaterThan)
SIMD_METHOD("CompareLessEqual", SN_CompareLessEqual)
SIMD_METHOD("CompareLessThan", SN_CompareLessThan)
SIMD_METHOD("CompareNotEqual", SN_CompareNotEqual)
SIMD_METHOD("CompareNotLessEqual", SN_CompareNotLessEqual)
SIMD_METHOD("CompareNotLessThan", SN_CompareNotLessThan)
SIMD_METHOD("CompareOrdered", SN_CompareOrdered)
SIMD_METHOD("CompareUnordered", SN_CompareUnordered)
SIMD_METHOD("ConvertToDouble", SN_ConvertToDouble)
SIMD_METHOD("ConvertToFloat", SN_ConvertToFloat)
SIMD_METHOD("ConvertToInt", SN_ConvertToInt)
SIMD_METHOD("ConvertToIntTruncated", SN_ConvertToIntTruncated)
SIMD_METHOD(".ctor", SN_ctor)
SIMD_METHOD("Duplicate", SN_Duplicate)
SIMD_METHOD("DuplicateHigh", SN_DuplicateHigh)
SIMD_METHOD("DuplicateLow", SN_DuplicateLow)
SIMD_METHOD("ExtractByteMask", SN_ExtractByteMask)
SIMD_METHOD("get_W", SN_get_W)
SIMD_METHOD("get_X", SN_get_X)
SIMD_METHOD("get_Y", SN_get_Y)
SIMD_METHOD("get_Z", SN_get_Z)
SIMD_METHOD("get_V0", SN_get_V0)
SIMD_METHOD("get_V1", SN_get_V1)
SIMD_METHOD("get_V2", SN_get_V2)
SIMD_METHOD("get_V3", SN_get_V3)
SIMD_METHOD("get_V4", SN_get_V4)
SIMD_METHOD("get_V5", SN_get_V5)
SIMD_METHOD("get_V6", SN_get_V6)
SIMD_METHOD("get_V7", SN_get_V7)
SIMD_METHOD("get_V8", SN_get_V8)
SIMD_METHOD("get_V9", SN_get_V9)
SIMD_METHOD("get_V10", SN_get_V10)
SIMD_METHOD("get_V11", SN_get_V11)
SIMD_METHOD("get_V12", SN_get_V12)
SIMD_METHOD("get_V13", SN_get_V13)
SIMD_METHOD("get_V14", SN_get_V14)
SIMD_METHOD("get_V15", SN_get_V15)
SIMD_METHOD("set_W", SN_set_W)
SIMD_METHOD("set_X", SN_set_X)
SIMD_METHOD("set_Y", SN_set_Y)
SIMD_METHOD("set_Z", SN_set_Z)
SIMD_METHOD("set_V0", SN_set_V0)
SIMD_METHOD("set_V1", SN_set_V1)
SIMD_METHOD("set_V2", SN_set_V2)
SIMD_METHOD("set_V3", SN_set_V3)
SIMD_METHOD("set_V4", SN_set_V4)
SIMD_METHOD("set_V5", SN_set_V5)
SIMD_METHOD("set_V6", SN_set_V6)
SIMD_METHOD("set_V7", SN_set_V7)
SIMD_METHOD("set_V8", SN_set_V8)
SIMD_METHOD("set_V9", SN_set_V9)
SIMD_METHOD("set_V10", SN_set_V10)
SIMD_METHOD("set_V11", SN_set_V11)
SIMD_METHOD("set_V12", SN_set_V12)
SIMD_METHOD("set_V13", SN_set_V13)
SIMD_METHOD("set_V14", SN_set_V14)
SIMD_METHOD("set_V15", SN_set_V15)
SIMD_METHOD("HorizontalAdd", SN_HorizontalAdd)
SIMD_METHOD("HorizontalSub", SN_HorizontalSub)
SIMD_METHOD("InterleaveHigh", SN_InterleaveHigh)
SIMD_METHOD("InterleaveLow", SN_InterleaveLow)
SIMD_METHOD("InvSqrt", SN_InvSqrt)
SIMD_METHOD("LoadAligned", SN_LoadAligned)
SIMD_METHOD("Max", SN_Max)
SIMD_METHOD("Min", SN_Min)
SIMD_METHOD("MultiplyStoreHigh", SN_MultiplyStoreHigh)
SIMD_METHOD("op_Addition", SN_op_Addition)
SIMD_METHOD("op_BitwiseAnd", SN_op_BitwiseAnd)
SIMD_METHOD("op_BitwiseOr", SN_op_BitwiseOr)
SIMD_METHOD("op_Division", SN_op_Division)
SIMD_METHOD("op_Equality", SN_op_Equality)
SIMD_METHOD("op_ExclusiveOr", SN_op_ExclusiveOr)
SIMD_METHOD("op_Explicit", SN_op_Explicit)
SIMD_METHOD("op_Inequality", SN_op_Inequality)
SIMD_METHOD("op_LeftShift", SN_op_LeftShift)
SIMD_METHOD("op_Multiply", SN_op_Multiply)
SIMD_METHOD("op_RightShift", SN_op_RightShift)
SIMD_METHOD("op_Subtraction", SN_op_Subtraction)
SIMD_METHOD("PackWithSignedSaturation", SN_PackWithSignedSaturation)
SIMD_METHOD("PackWithUnsignedSaturation", SN_PackWithUnsignedSaturation)
SIMD_METHOD("PrefetchTemporalAllCacheLevels", SN_PrefetchTemporalAllCacheLevels)
SIMD_METHOD("PrefetchTemporal1stLevelCache", SN_PrefetchTemporal1stLevelCache)
SIMD_METHOD("PrefetchTemporal2ndLevelCache", SN_PrefetchTemporal2ndLevelCache)
SIMD_METHOD("PrefetchNonTemporal", SN_PrefetchNonTemporal)
SIMD_METHOD("Reciprocal", SN_Reciprocal)
SIMD_METHOD("ArithmeticRightShift", SN_ArithmeticRightShift)
SIMD_METHOD("LogicalRightShift", SN_LogicalRightShift)
SIMD_METHOD("ShuffleHigh", SN_ShuffleHigh)
SIMD_METHOD("ShuffleLow", SN_ShuffleLow)
SIMD_METHOD("Shuffle", SN_Shuffle)
SIMD_METHOD("SignedPackWithSignedSaturation", SN_SignedPackWithSignedSaturation)
SIMD_METHOD("SignedPackWithUnsignedSaturation", SN_SignedPackWithUnsignedSaturation)
SIMD_METHOD("Sqrt", SN_Sqrt)
SIMD_METHOD("StoreAligned", SN_StoreAligned)
SIMD_METHOD("StoreNonTemporal", SN_StoreNonTemporal)
SIMD_METHOD("SubtractWithSaturation", SN_SubtractWithSaturation)
SIMD_METHOD("SumOfAbsoluteDifferences", SN_SumOfAbsoluteDifferences)
SIMD_METHOD("UnpackHigh", SN_UnpackHigh)
SIMD_METHOD("UnpackLow", SN_UnpackLow)
